pub struct Transport { /* private fields */ }Expand description
Shared transport holding:
- a single UDP socket
- a map of remote_addr -> channel sender
- a task to read incoming datagrams and dispatch them
- a task to remove connection entries when Connections drop
Implementations